#
# spec file for package sblim-gather
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sblim-gather
BuildRequires:  gcc-c++
BuildRequires:  libvirt-devel > 0.7
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  sblim-cmpi-base-devel
BuildRequires:  sblim-indication_helper-devel
BuildRequires:  sblim-testsuite
%if 0%{?rhel_version} == 0 && 0%{?centos_version} == 0
BuildRequires:  openslp-devel
%endif
BuildRequires:  glib2-devel
%if 0%{?suse_version}
BuildRequires:  libtool
BuildRequires:  pkg-config
%else
BuildRequires:  pkgconfig
%endif
Url:            http://sblim.wiki.sourceforge.net/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        SBLIM Performance Data Gatherer and Provider
License:        EPL-1.0
Group:          System/Management
Version:        2.2.8
Release:        4.3
Source0:        http://prdownloads.sourceforge.net/sblim/sblim-gather-%{version}.tar.bz2
Patch1:         sblim-gather-2.1.8_pointers.patch
Patch3:         sblim-gather-2.2.2-redefinition.patch
Patch4:         sblim-gather-2.2.3-initstyle.patch
# PATCH-FIX-UPSTREAM sblim-gather-%{version}-drop-libsysfs.patch [ bnc#860102 ] pwieczorkiewicz@suse.de -- Drop libsysfs requirement
Patch5:         sblim-gather-2.2.8-drop-libsysfs.patch
Provides:       sblim-gather-pluginz = %{version}
Requires(pre):  cim-server

%description
The purpose of this package is to implement the DMTF CIM Metrics Model
for Linux, making it available via a CIMOM supporting/supported by the
CMPI provider interface.

While the Gatherer and it's plugins can be used standalone, the
greatest benefit comes from using it in conjuction with a CIM Object
Manager (CIMOM) like Pegasus (The Open Group). Basically it allows to
remoteley obtain performance information about a Linux system. For more
information about CIM and the CIM Metrics Model you are referred to the
Distributed Management Task Force (DMTF) at http://www.dmtf.org.

This package is containing the agents and control programs which can be
deployed stand-alone.



Authors:
--------
    SBLIM Project

%package provider
Summary:        SBLIM Gatherer Provider
Group:          System/Management
Requires:       %{name} = %{version}
Requires:       cim-server
Requires:       sblim-cmpi-base
Provides:       sblim-gather-pluginz-provider = %{version}

%description provider
This package is containing the CIM Providers for the SBLIM Gatherer.



Authors:
--------
    SBLIM Project

%package devel
Summary:        SBLIM Gatherer Development Support
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package is needed to develop new plugins for the gatherer.



Authors:
--------
    SBLIM Project

%package test
Summary:        SBLIM Gatherer Testcase Files
Group:          System/Management
Requires:       %{name} = %{version}
Requires:       %{name}-provider = %{version}
Requires:       sblim-testsuite

%description test
SBLIM Gatherer Testcase Files for the SBLIM Testsuite



Authors:
--------
    SBLIM Project

%prep
%setup -n %{name}-%{version}
%patch1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
autoreconf -fi
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure --enable-z
%{__make}

%install
%if 0%{?suse_version}
%makeinstall docdir=%{_docdir}/%{name}
%else
make install DESTDIR=%{buildroot} docdir=%{_docdir}/%{name}-%{version}
%endif
find %{buildroot} -type f -name \*.la -print0 -delete

%clean
%{__rm} -rf %{buildroot}

%define MOF Linux_IPProtocolEndpointMetric,Linux_LocalFileSystemMetric,Linux_Metric,Linux_NetworkPortMetric,Linux_OperatingSystemMetric,Linux_ProcessorMetric,Linux_UnixProcessMetric,Linux_XenMetric,Linux_zCECMetric,Linux_zCHMetric,Linux_zECKDMetric,Linux_zLPARMetric
%define REGISTRATION %{_datadir}/%{name}/{%{MOF}}.registration
%define SCHEMA %{_datadir}/%{name}/{%{MOF}}.mof

%post provider
# compile MOF
%{_datadir}/%{name}/provider-register.sh \
        -r %{REGISTRATION} -m %{SCHEMA} >/dev/null 2>&1 || true

%preun provider
if [ "$1" = "0" ]; then
	%{_datadir}/%{name}/provider-register.sh \
        	-r %{REGISTRATION} -m %{SCHEMA} >/dev/null 2>&1 || true
fi

%postun provider -p /sbin/ldconfig

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/gatherd.conf
%config(noreplace) %{_sysconfdir}/reposd.conf
%{_sysconfdir}/init.d/gatherer
%ghost %{_localstatedir}/run/gather
%{_bindir}/*
%{_sbindir}/*
%if 0%{?suse_version}
%doc %{_docdir}/%{name}
%else
%doc %{_docdir}/%{name}-%{version}
%endif
%dir %{_libdir}/gather
%dir %{_libdir}/gather/mplug
%dir %{_libdir}/gather/rplug
%{_libdir}/gather/mplug/*.so
%{_libdir}/gather/rplug/*.so
%{_libdir}/*.so.*

%files provider
%defattr(-,root,root,-)
%{_libdir}/cmpi/*.so
%dir %{_libdir}/gather/cplug
%{_libdir}/gather/cplug/*.so
%{_datadir}/%{name}

%files devel
%defattr(-,root,root,-)
%{_includedir}/gather
%{_libdir}/libgather.so
%{_libdir}/libmcserv.so
%{_libdir}/librcserv.so
%{_libdir}/librepos.so
%{_libdir}/librgather.so
%{_libdir}/librrepos.so
%{_libdir}/libhypfs.so
%{_libdir}/liblparutil.so
%{_libdir}/libsysfswrapper.so
%{_libdir}/libchannelutil.so
%{_libdir}/libgatherutil.so
%{_libdir}/libOSBase_MetricUtil.so

%files test
%defattr(-,root,root,-)
%{_datadir}/sblim-testsuite/*

%changelog
* Mon Jan 27 2014 pwieczorkiewicz@suse.com
- Update to 2.2.8
  Bugs fixed:
  - 3603719 Clean up configuration toolchain and fix DSO linking
  - 3196679 remove sysfs dependency when not building z plugins
  - #2023 clean up compile warnings
  - #2045 Metric assoc providers don't honor result class
  - #1650 libvirt metric associations need to be to root/virt
  Features added:
  - 2284848 CPU utilization should account for steal-time
  Note: Above numbers are upstream bug IDs.
- sblim-gather-2.2.8-drop-libsysfs.patch:
  Drop libsysfs requirement, correct whitespaces. (bnc#860102)
* Fri Nov 30 2012 kkaempf@suse.com
- Update to 2.2.7
  Bugs fixed:
  - 3557673 distcheck should check for system z plugins
  - 3573309 large memory counters overflow raw metric buffer
  - 3573315 thread cleanup segv if gather libs unloaded
  - 3580235 use setProperty for instance keys under Pegasus
  Features added:
  - 3019058 add man pages/help for gatherd and reposd
  - 3590926 add man page for reposdump utility
* Fri Oct 26 2012 kkaempf@suse.com
- SuSEconfig gone: Add one more check for SUSE buildenv
- move libOSBase_MetricUtil.so from -provider to -devel
* Mon Oct  1 2012 kkaempf@suse.com
- Require libvirt > 0.7
* Fri Aug 17 2012 vdziewiecki@suse.com
- Update to Version 2.2.6
  Bugs fixed:
  - 3530668 Duration values always reported as zero
  - 3545751 BaseMetricValue.Volatile should be false
  - 3552310 incorrect metric definition for VirtualState
  - 2811884 dsp1053 unique BaseMetricDefinition.Name
  - 3554130 sample interval config warning
  - 3554137 multiple definitions of CMPI_false
  - 3557552 make distcheck fails
  Features added:
  - 3031802 add support for CIM property filters
  - 3552873 DSP1053 v1.0.1 profile conformance
* Wed Apr  4 2012 kkaempf@suse.com
- Update to Version 2.2.5
  Bugs fixed:
  - 3482806 blkio not updated for inactive domains
  - 3482867 virDomainBlkStats garbage if domain undefined
  - 3482869 segv parsing xml if domain becomes undefined
  - 3482875 virDomBlkInfo garbage if domain undefined
  - 3514701 segv parsing xml if no defined source media
- Update to Version 2.2.4
  Bugs fixed:
  - 3394202 large network counters overflow raw metric buffer
  - 3412635 bad string allocations
  - 3419837 bad alloc and unsigned returns in metricVirt
  - 3397109 UnixProcess plugins occasionally crashes
  - 3429346 libvirt race conditions
  - 3429347 initscript incorrect return code
  - 3438050 clean up IPProtocolEP raw data parsing
  - 3439114 storage plugin leaks file descriptors
  Features added:
  - 3438074 add packet drop metrics to IPProtocolEP
  - 3439075 add Host Block IO metrics
  - 3444879 add VM Block IO Metrics
  Features removed:
  - 3098510 add process name to UnixProcessMetric
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 kkaempf@suse.com
- Update to 2.2.3
  Bugs fixed:
  - 3275169 bash error reported in provider bootstrap scripts
  - 3289931 long vm names cause buffer overflow
  - 3181085 Mandatory Properties not instantiated: CIM_MetricServiceCapa
  - 3005596 virt plugin only connects to libvirtd at load
  - 3302709 leak libvir connections when no domains
  Features added:
  - 3300216 new KVM scheduler counter metrics
  - 3302712 log libvirt connection failures
* Wed Jan  5 2011 kkaempf@novell.com
- update to 2.2.2
  Bugs fixed:
  - 3039719 normalize virtual server metric sample interval
  - 3049802 plugin load generates error if already loaded
  - 3074431 change VSState to a Point metric
  - 3074452 change ActiveVirtualProcessors to point metric
  - 1845491 gather reposdump facility segfaults
  - 3078358 no metrics collected for inactive virtual servers
  - 3109840 mlog with arguments segfaults on M_SHOW
  - 3109852 TimeStamp property should be end of interval
  Features added:
  - 3098510 add process name to UnixProcessMetric
* Tue Sep 14 2010 kkaempf@novell.com
- Fix RH/Fedora build
* Wed Sep  8 2010 aj@suse.de
- BuildRequire sysfsutils-devel
* Mon Mar 29 2010 kkaempf@novell.com
- Sysfs wrapper incorrectly calls open_device_path in stead of
  open_device_tree (bnc#590239)
* Wed Oct 14 2009 mhrusecky@suse.cz
- sending current development version to SLE11 SP1 (fate#307089)
* Fri Oct  2 2009 mhrusecky@suse.cz
- updated to 2.2.0
  * 2666450: gather: update metricXen.readme with correct metrics
  * 2787610: gather: port Xen metrics to libvirt API
  * 2787612: gather: add KVM metric support
  * 2789260: gather: KVM HostFreePhysicalMemory uses first domain name
  * 2790901: gather: need to test for libvirt-devel in configure
  script
  * 2790937: Xen/KVM and zLinux metrics should be optional
  * 2791472: plugins should be built as dlopen modules
  * 2791496: fix linker paths to gather utility libraries
  * 2794542: migrate license from CPL to EPL
  * 2811680: add used memory metrics
  * 2811685: add packet rate metrics
  * 2811885: add Service and Capabilities providers
  * 2811897: add Service method provider
  * 2811892: add Service and Capabilities associations
  * 2811900: DSP1053 Base Metric Profile Conformance
- sblim-gather-2.1.5-libtool_modules.patch and
  sblim-gather-2.1.5-linkerpaths.patch were fixed upstream
* Tue May 12 2009 mhrusecky@suse.cz
- ignoring tog-pegasus during build
* Fri Mar  6 2009 mhrusecky@suse.cz
- updated to 2.1.9
  * Fixed 2655459: Need AM_PROG_CC_C_O for reposdump.c
  * Fixed 2655422: metricOS plugin reads from wrong end of stderr pipe
  * Fixed 2655431: add <stdio.h> to cimplugLocalFilesystem
  * Fixed 1942072: sblim-gather doesn't build with glibc-2.8
  * Fixed 2508615: add CMPIStatus to indication function return
- sblim-gather-2.1.5-missing-includes.patch is not needed anymore as it
  is fixed in upstream
* Tue Jan 20 2009 mhrusecky@suse.cz
- updated to 2.1.8
  * Fixed 2414836: replace vendor defined timescope with point
  * Fixed 2385101: remove compile warnings
  * Fixed 2384020: incorrect process count
  * Fixed 2322593: TotalCPUTimePerc should be based on metric interval
  * Fixed 2375829: raw processor metric identical across multipe cpus
  * Fixed 2347308: processor metric assigns bad measureElementName
  * Fixed 2172899: xenMetric segfaults on non-running DomU's
  * Fixed 2065755: getInstance always reports zero plugins
- registering all mof files at once
* Fri Sep 12 2008 mmarek@suse.cz
- switch to sfcb
* Mon Apr 14 2008 mmarek@suse.cz
- updated to 2.1.6
  Fixed sf.net#1845491: reposdump segfault without arguments.
- fixed build with glibc 2.8 (missing-includes.patch)
- added gather-reposdump.patch which is apparently missing in the
  2.1.6 release (see https://sourceforge.net/tracker/?func=detail&atid=712784&aid=1845491&group_id=128809)
* Thu Nov  1 2007 mmarek@suse.cz
- updated to version 2.1.5
  fixed upstream bugs:
  * 1808017 Added Lifecycle Indication Support
  * 1808022 Fixed false test script failure report
  * 1810856 Fixed data retrieval issue with variable intervals
  * 1815686 Added reposdump utility to offload historical data
* Wed Jul 11 2007 mrueckert@suse.de
- update to version 2.1.4:
  - 1736593 Fixed XEN gatherd is not running
  - 1744262 Fixed compilation problems with tog-pegasus headers
  - 1751133 Fixed gather indication provider not working properly
  - 1751173 Fixed potential memory problem in Xen plugin
- additional changes from 2.1.3
  - 1648800 Fixed gather testsuite start script fails with https
  - 1652565 Fixed build problem with libsysfs v2
- added sblim-gather-2.1.4-libtool_modules.patch:
  the plugins dont need a .so version. patched makefiles to avoid it
  and adapted the filelist
- removed sblim-gather-2.1.2-testscript_bug_240778.patch:
  included in 2.1.3
* Thu Mar 15 2007 mrueckert@suse.de
- synced requires/provides with upstream spec (#255052)
* Wed Feb  7 2007 mrueckert@suse.de
- Fix requires on cim server.
* Fri Feb  2 2007 mrueckert@suse.de
- added sblim-gather-2.1.2-testscript_bug_240778.patch:
  Fix testsuite for https only cim-server (#240778)
* Fri Feb  2 2007 mrueckert@suse.de
- split package into logical pieces (base package, provider,devel
  and test subpackages) (#240800)
- added /var/run/gather (#240800)
- marked config files as config(noreplace)
- removed unneeded .la files
- run ldconfig
* Fri Jan 12 2007 mrueckert@suse.de
- update to version 2.1.2:
  * Changes in Version 2.1.2:
  - 1525914 Fixed repository overwrite by z channel plugin.
  - 1585629 Fixed z channel timestamp wrap
  - 1585628 Fixed invalid CPU values for z LPARs and CEC
  - 1565458 Fixed CIMOM crash after invalid getinstance ops
  - 1613105 Fixed handling of unsigned 32-bit integers
  * Changes  in Version 2.1.1:
  - 1468385 Fixed 32bit value display
  - 1474178 Fixed bogus file ownerships in RPM specfiles
  - 1506037 Fixed testsuite for https CIM server connections
  - 1509900 Fixed memory corruption in Xen Plugin
    Features added:
  - 1509902 Added plugins for IBM System z
  * Changes in Version 2.1.0
    Features added:
  - 1427714 Added new config properties for automatic plugin loading.
  - 1429155 Added new config option for sample interval override.
  - 1436488 Added top-N support for metric values.
  - 1436591 Added new config option to specify the repository expiration.
  - 1436671 New plugin for Xen.
  - 1441802 Added new config option for synchronized sampling.
  - 1450569 Multiple gather installations can coexist now on one system.
  - 1454734 Support for seperate devel package added.
    Bugs fixed:
  - 1395363 Removed provider postinstall location dependencies.
  - 1441804 Fixed spec file
  - 1446497 Removed metric instance number limit
  - 1449436 Enhanced metric repository performance for large data volumes
  - 1449628 Fixed segfault in Xen plugin
  - 1450216 Enhanced filter performance by adaptive sorting algorithms
  - 1454722 Fixed potential memory overwrite in local communications code
  - 1464845 Fixed potential repository failure for interval metrics
  * Changes in Version 2.0.4
    Bugs fixed:
  - 1430516 Fixed unrecoverable disconnect.
  - 1443997 Fixed handling of partially loaded repository plugin sets
  - 1444272 Fixed coredump for NULL unit fields
  - 1444711 Fixed CPU time display units (now milliseconds)
  - 1444826 Fix some portability issues
- updated sblim-gather-2.0.3_linkerpaths.patch for 2.1.2.
  new name sblim-gather-2.1.2_linkerpaths.patch.
- use upstream solution for sblim-gather-2.0.3_static_overflow.patch
- updated sblim-gather-2.0.3_pointers.patch for 2.1.2.
  new name sblim-gather-2.1.2_pointers.patch.
* Wed Mar  1 2006 mrueckert@suse.de
- update to version 2.0.3
  * 1422395 Fixed MetricInstance unidirectional misbehavior. (2.0.3)
  * 1426051 Fixed interoperability issues between 32 and 64 bit
  systems. (2.0.3)
  * 1376211 Fixed testsuite false failure reports. (2.0.2)
  * 1236584 Enhanced compatibility with tog-pegasus. (2.0.1)
  * Gatherer is now fully distributable: a central repository node
  can collect data from a large number of remote nodes running
  the gatherd daemon. (2.0.0)
- removed all patches -> no longer valid as the build system
  switched to auto*
- added patches
  * sblim-gather-2.0.3_linkerpaths.patch
  use .la files instead of -l on intree libraries
  * sblim-gather-2.0.3_static_overflow.patch
  fix a static buffer overflow
  * sblim-gather-2.0.3_pointers.patch
  fix a few warnings regarding mismatching pointer sizes
- compile with -fno-strict-aliasing
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 14 2005 ro@suse.de
- fix filelist
* Tue Dec 13 2005 mrueckert@suse.de
- update to 1.0.11
- build against openwbem
- build with optflags
- use new syntax of loadmof/rmmof
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Thu May 20 2004 nashif@suse.de
- fixed #40885: sblim-gather provider hangs Pegasus and OpenWBEM
* Thu May 13 2004 nashif@suse.de
- Initial Release ( 0.7.4)
